### Name: pcrsim
### Title: Simulation of sigmoidal qPCR data with goodness-of-fit analysis
###   for different models
### Aliases: pcrsim
### Keywords: models nonlinear

### ** Examples

## generate initial model
m <- pcrfit(reps, 1, 2, l4)

## simulate homoscedastic error
## and test initial model, w3 and l5 
## model on data
res <- pcrsim(cyc = 1:30, model = l4, par = coef(m),
              error = 0.2, nsim = 20, fitmodel = list(l4, w3, l5))

## use heteroscedastic noise typical for 
## qPCR: more noise at lower fluorescence
## Not run: 
##D res2 <- pcrsim(cyc = 1:30, model = l4, par = coef(m),
##D               error = 0.01, errfun = function(y) 1/y,
##D               nsim = 20, fitmodel = list(l4, w3, l5))
## End(Not run)

## get 95% confidence interval for 
## the models GOF in question (l4, w3, l5) 
## Not run: 
##D res <- pcrsim(cyc = 1:30, model = l4, par = coef(m),
##D               error = 0.2, nsim = 20, fitmodel = list(l4, w3, l5),
##D               statfun = function(y) quantile(y, c(0.025, 0.975)))
##D res$statList  
## End(Not run)  

## show best model for each simulation
## based on different GOF measures
## Not run: 
##D res <- pcrsim(cyc = 1:30, model = l4, par = coef(m),
##D               error = 0.2, nsim = 20, fitmodel = list(l4, w3, l5),
##D               select = TRUE)
##D res$modelMat
## End(Not run) 



